Changelog
=========

1.1.0  
-----
Released 2017-02-26 
  * New backend ServerDirectory

1.0.1
-----
Released 2017-02-25
  * Documentation fixes

1.0.0
-----
Released 2017-02-25
  * Initial version supporting backends Directory and MMT



